==> miniorange_2fa-8.x-3.10.tar.gz: miniorange_2fa/src/Form/MoAuthRequestDemo.php <==
<?php

namespace Drupal\miniorange_2fa\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\Ajax\RedirectCommand;
use Drupal\Core\Form\FormStateInterface;
use Drupal\miniorange_2fa\MoAuthUtilities;
use Drupal\miniorange_2fa\AuthenticationType;
use Drupal\miniorange_2fa\Miniorange2FASupport;

class MoAuthRequestDemo extends FormBase
{
    public function getFormId() {
        return 'miniorange_2fa_request_demo';
    }

    public function buildForm(array $form, FormStateInterface $form_state, $options = NULL) {
        $form['#prefix'] = '<div id="modal_example_form">';
        $form['#suffix'] = '</div>';
        $form['status_messages'] = [
            '#type' => 'status_messages',
            '#weight' => -10,
        ];

        $form['miniorange_2fa_content'] = array(
            '#markup' => 'Please fill out the below details and submit!!'
        );

        $options = array(
            AuthenticationType::$LASTPASS_AUTHENTICATOR['code']  => AuthenticationType::$LASTPASS_AUTHENTICATOR['name'],
            AuthenticationType::$GOOGLE_AUTHENTICATOR['code']    => AuthenticationType::$GOOGLE_AUTHENTICATOR['name'],
            AuthenticationType::$DUO_AUTHENTICATOR['code']       => AuthenticationType::$DUO_AUTHENTICATOR['name'],
            AuthenticationType::$AUTHY_AUTHENTICATOR['code']     => AuthenticationType::$AUTHY_AUTHENTICATOR['name'],
            AuthenticationType::$MICROSOFT_AUTHENTICATOR['code'] => AuthenticationType::$MICROSOFT_AUTHENTICATOR['name'],
            AuthenticationType::$OKTA_VERIFY['code']             => AuthenticationType::$OKTA_VERIFY['name'],
            AuthenticationType::$SMS['code']                     => AuthenticationType::$SMS['name'],
            AuthenticationType::$EMAIL['code']                   => AuthenticationType::$EMAIL['name'],
            AuthenticationType::$SMS_AND_EMAIL['code']           => AuthenticationType::$SMS_AND_EMAIL['name'],
            AuthenticationType::$OTP_OVER_PHONE['code']          => AuthenticationType::$OTP_OVER_PHONE['name'],
            AuthenticationType::$QR_CODE['code']                 => AuthenticationType::$QR_CODE['name'],
            AuthenticationType::$PUSH_NOTIFICATIONS['code']      => AuthenticationType::$PUSH_NOTIFICATIONS['name'],
            AuthenticationType::$SOFT_TOKEN['code']              => AuthenticationType::$SOFT_TOKEN['name'],
            AuthenticationType::$HARDWARE_TOKEN['code']          => AuthenticationType::$HARDWARE_TOKEN['name'],
        );

        $form['miniorange_2fa_content'] = array(
            '#type' => 'checkboxes',
            '#options' => $options,
            '#title' => t('Select 2FA methods you are most interested in:'),
            '#prefix' => '<div class="container-inline">',
            '#suffix' => '</div>',
            '#required' => TRUE,
        );

        $form['miniorange_2fa_architecture'] = array(
            '#type' => 'radios',
            '#title' => t('Drupal Architecture:'),
            '#default_value' => 'Traditional/Normal',
            '#description' => t('Choose if you are using the Headless/Decoupled architecture for your Drupal site.'),
            '#options' => array('Traditional/Normal' => t('Traditional/Normal'), 'Headless/Decoupled' => t('Headless/Decoupled')),
            '#required' => TRUE,
            '#prefix' => '<div class="container-inline">',
            '#suffix' => '</div>',
        );

        $form['miniorange_2fa_usecase'] = array(
            '#type' => 'textarea',
            '#title' => t('Usecase/Requirements (Optional):'),
            '#rows' => 8,
        );

        $form['actions'] = array('#type' => 'actions');
        $form['actions']['send'] = [
            '#type' => 'submit',
            '#value' => $this->t('Submit'),
            '#attributes' => [
                'class' => [
                    'use-ajax',
                ],
            ],
            '#ajax' => [
                'callback' => [$this, 'submitModalFormAjax'],
                'event' => 'click',
            ],
        ];

        $form['#attached']['library'][] = 'core/drupal.dialog.ajax';
        return $form;
    }

    public function submitModalFormAjax(array $form, FormStateInterface $form_state) {
        $response = new AjaxResponse();
        // If there are any form errors, AJAX replace the form.
        if ( $form_state->hasAnyErrors() ) {
            $response->addCommand(new ReplaceCommand('#modal_example_form', $form));
        } else {
            $utilities = new MoAuthUtilities();
            $variables_and_values = array(
              'mo_auth_customer_admin_email',
            );
            $mo_db_values = $utilities->miniOrange_set_get_configurations( $variables_and_values, 'GET' );

            $userAccountDetails = '<strong>User account email: </strong>' . $mo_db_values['mo_auth_customer_admin_email'];

            $form_values = $userAccountDetails . '<br><br><strong>Interested 2FA mentods: </strong>' . implode(', ', $form['miniorange_2fa_content']['#value']);
            $form_values .= '<br><br><strong>Drupal Architecture: </strong>' . $form['miniorange_2fa_architecture']['#value'];
            $form_values .= '<br><br><strong>Usecase/Requirements: </strong>' . $form['miniorange_2fa_usecase']['#value'];

            $query = "<br><br>Account Details and Usecase:<br><pre style=\"border:1px solid #444;padding:10px;\"><code>" . $form_values . "</code></pre>";

            $support = new Miniorange2FASupport( $mo_db_values['mo_auth_customer_admin_email'], '', $query, 'Trial Request' );
            $support_response = $support->sendTrialRequest();

            \Drupal::messenger()->addStatus(t('Success! We shall review and add the trial licence under your account. You can click the Check Licence button periodically, to check whether this has been completed.'));
            $_POST['value_check'] = 'False';
            $response->addCommand(new RedirectCommand(\Drupal\Core\Url::fromRoute('miniorange_2fa.customer_setup')->toString()));
        }
        return $response;
    }

    public function validateForm(array &$form, FormStateInterface $form_state) { }

    public function submitForm(array &$form, FormStateInterface $form_state) { }

    protected function getEditableConfigNames() {
        return ['config.miniorange_2fa_remove_account'];
    }
}

==> miniorange_2fa-8.x-4.1.tar.gz: miniorange_2fa/src/Form/MoAuthRequestDemo.php <==
<?php

namespace Drupal\miniorange_2fa\Form;

use Drupal\Core\Url;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\Ajax\RedirectCommand;
use Drupal\Core\Form\FormStateInterface;
use Drupal\miniorange_2fa\MoAuthUtilities;
use Drupal\miniorange_2fa\AuthenticationType;
use Drupal\miniorange_2fa\Miniorange2FASupport;

class MoAuthRequestDemo extends FormBase
{
    public function getFormId() {
        return 'miniorange_2fa_request_demo';
    }

    public function buildForm(array $form, FormStateInterface $form_state, $options = NULL) {
        $form['#prefix'] = '<div id="modal_example_form">';
        $form['#suffix'] = '</div>';
        $form['status_messages'] = [
            '#type' => 'status_messages',
            '#weight' => -10,
        ];

        $form['miniorange_2fa_content'] = array(
            '#markup' => 'Please fill out the below details and submit!!'
        );

        $options = array(
            AuthenticationType::$LASTPASS_AUTHENTICATOR['code']  => AuthenticationType::$LASTPASS_AUTHENTICATOR['name'],
            AuthenticationType::$GOOGLE_AUTHENTICATOR['code']    => AuthenticationType::$GOOGLE_AUTHENTICATOR['name'],
            AuthenticationType::$DUO_AUTHENTICATOR['code']       => AuthenticationType::$DUO_AUTHENTICATOR['name'],
            AuthenticationType::$AUTHY_AUTHENTICATOR['code']     => AuthenticationType::$AUTHY_AUTHENTICATOR['name'],
            AuthenticationType::$MICROSOFT_AUTHENTICATOR['code'] => AuthenticationType::$MICROSOFT_AUTHENTICATOR['name'],
            AuthenticationType::$OKTA_VERIFY['code']             => AuthenticationType::$OKTA_VERIFY['name'],
            AuthenticationType::$SMS['code']                     => AuthenticationType::$SMS['name'],
            AuthenticationType::$EMAIL['code']                   => AuthenticationType::$EMAIL['name'],
            AuthenticationType::$SMS_AND_EMAIL['code']           => AuthenticationType::$SMS_AND_EMAIL['name'],
            AuthenticationType::$OTP_OVER_PHONE['code']          => AuthenticationType::$OTP_OVER_PHONE['name'],
            AuthenticationType::$QR_CODE['code']                 => AuthenticationType::$QR_CODE['name'],
            AuthenticationType::$PUSH_NOTIFICATIONS['code']      => AuthenticationType::$PUSH_NOTIFICATIONS['name'],
            AuthenticationType::$SOFT_TOKEN['code']              => AuthenticationType::$SOFT_TOKEN['name'],
            AuthenticationType::$HARDWARE_TOKEN['code']          => AuthenticationType::$HARDWARE_TOKEN['name'],
        );

        $form['miniorange_2fa_content'] = array(
            '#type' => 'checkboxes',
            '#options' => $options,
            '#title' => t('Select 2FA methods you are most interested in:'),
            '#prefix' => '<div class="container-inline">',
            '#suffix' => '</div>',
            '#required' => TRUE,
        );

        $form['miniorange_2fa_architecture'] = array(
            '#type' => 'radios',
            '#title' => t('Drupal Architecture:'),
            '#default_value' => 'Traditional/Normal',
            '#description' => t('Choose if you are using the Headless/Decoupled architecture for your Drupal site.'),
            '#options' => array('Traditional/Normal' => t('Traditional/Normal'), 'Headless/Decoupled' => t('Headless/Decoupled')),
            '#required' => TRUE,
            '#prefix' => '<div class="container-inline">',
            '#suffix' => '</div>',
        );

        $form['miniorange_2fa_usecase'] = array(
            '#type' => 'textarea',
            '#title' => t('Usecase/Requirements (Optional):'),
            '#rows' => 8,
        );

        $form['actions'] = array('#type' => 'actions');
        $form['actions']['send'] = [
            '#type' => 'submit',
            '#value' => $this->t('Submit'),
            '#attributes' => [
                'class' => [
                    'use-ajax',
                ],
            ],
            '#ajax' => [
                'callback' => [$this, 'submitModalFormAjax'],
                'event' => 'click',
            ],
        ];

        $form['#attached']['library'][] = 'core/drupal.dialog.ajax';
        return $form;
    }

    public function submitModalFormAjax(array $form, FormStateInterface $form_state) {
        $response = new AjaxResponse();
        // If there are any form errors, AJAX replace the form.
        if ( $form_state->hasAnyErrors() ) {
            $response->addCommand(new ReplaceCommand('#modal_example_form', $form));
        } else {
            $utilities = new MoAuthUtilities();
            $variables_and_values = array(
              'mo_auth_customer_admin_email',
            );
            $mo_db_values = $utilities->miniOrange_set_get_configurations( $variables_and_values, 'GET' );

            $userAccountDetails = '<strong>User account email: </strong>' . $mo_db_values['mo_auth_customer_admin_email'];

            $form_values = $userAccountDetails . '<br><br><strong>Interested 2FA mentods: </strong>' . implode(', ', $form['miniorange_2fa_content']['#value']);
            $form_values .= '<br><br><strong>Drupal Architecture: </strong>' . $form['miniorange_2fa_architecture']['#value'];
            $form_values .= '<br><br><strong>Usecase/Requirements: </strong>' . $form['miniorange_2fa_usecase']['#value'];

            $query = "<br><br>Account Details and Usecase:<br><pre style=\"border:1px solid #444;padding:10px;\"><code>" . $form_values . "</code></pre>";

            $support = new Miniorange2FASupport( $mo_db_values['mo_auth_customer_admin_email'], '', $query, 'Trial Request' );
            $support_response = $support->sendTrialRequest();

            \Drupal::messenger()->addStatus(t('Success! We shall review and add the trial licence under your account. You can click the Check Licence button periodically, to check whether this has been completed.'));
            $_POST['value_check'] = 'False';
            $response->addCommand(new RedirectCommand(Url::fromRoute('miniorange_2fa.customer_setup')->toString()));
        }
        return $response;
    }

    public function validateForm(array &$form, FormStateInterface $form_state) { }

    public function submitForm(array &$form, FormStateInterface $form_state) { }

    protected function getEditableConfigNames() {
        return ['config.miniorange_2fa_remove_account'];
    }
}
